Coverage for project/settings.py: 100%

# Coverage for project/settings.py : 100%

## 13 statements 13 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from .base_settings import * # noqa

2

3# SECURITY WARNING: keep the secret key used in production secret!

4 SECRET_KEY = 'u2zms+0ox65j55t97t7s-*(#w08vqi80+5)p=1x42b24#3yrlz' # noqa

5

6# SECURITY WARNING: don't run with debug turned on in production!

7 DEBUG = True

8

9 ALLOWED_HOSTS = ['localhost.kajala.com', 'testserver']

10

11 INSTALLED_APPS.append('django_extensions') # noqa

12

13# Database

14# https://docs.djangoproject.com/en/3.0/ref/settings/#databases

15

16 DATABASES = {

17 'default': {

18 'ENGINE': 'django.db.backends.postgresql_psycopg2',

19 'NAME': 'django_jutil',

20 'USER': 'dev',

21 'PASSWORD': 'dev', # noqa

22 'HOST': 'localhost',

23 'PORT': 5432,

24 'CONN_MAX_AGE': 180,

25 }

26}

27

28# IP stack (IP country code)

29 IPSTACK_TOKEN = 'b590ba81315cfe895c9701dadc1b9c05' # account: kajala@gmail.com

30

31# Emails

32# GF Money (SendGrid):

33 EMAIL_SENDGRID_API_KEY = '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' # noqa

34 EMAIL_HOST = 'smtp.sendgrid.net'

35 EMAIL_PORT = 587

36 EMAIL_USE_TLS = True

37 EMAIL_HOST_USER = 'apikey'

38 EMAIL_HOST_PASSWORD = EMAIL_SENDGRID_API_KEY # noqa

39# PURO (Microsoft Office 365):

40# DEFAULT_FROM_EMAIL = 'puro@puro.finance'

41# EMAIL_HOST = 'smtp.office365.com'

42# EMAIL_PORT = 587

43# EMAIL_USE_TLS = 1

44# EMAIL_HOST_USER = 'puro@puro.finance'

45# EMAIL_HOST_PASSWORD = 'Virta6973!' # noqa